@@ -6,7 +6,7 @@ from .._core import axis as ca
 from .kwargs import KWArgs
 from .sig_tools import inject_signature
 from .axis_transform import AxisTransform
-from .utils import cast, register, set_family, MAIN_FAMILY, CPP_FAMILY, set_module
+from .utils import cast, register, set_family, MAIN_FAMILY, set_module
 from .six import string_types
 
 import copy
@@ -80,6 +80,10 @@ class Axis(object):
     def metadata(self, value):
         self._ax.metadata = value
 
+    @metadata.deleter
+    def metadata(self):
+        self._ax.metadata = None
+
     @classmethod
     def _convert_cpp(cls, cpp_object):
         nice_ax = cls.__new__(cls)
@@ -109,12 +113,6 @@ class Axis(object):
 
         return begin, end
 
-
-# Mixin for main style classes
-# Contains common methods and properties to all Main module axes
-class MainAxisMixin(object):
-    __slots__ = ()
-
     def __repr__(self):
         return "{self.__class__.__name__}({args}{kwargs})".format(
             self=self, args=self._repr_args(), kwargs=self._repr_kwargs()
@@ -203,52 +201,6 @@ class MainAxisMixin(object):
         return self._ax.widths
 
 
-# Contains all common methods for cpp module axes
-class CppAxisMixin(object):
-    __slots__ = ()
-
-    def __repr__(self):
-        return repr(self._ax)
-
-    def options(self):
-        """
-        Return the options.  Fields:
-          .underflow - True if axes captures values that are too small
-          .overflow  - True if axes captures values that are too large
-                       (or non-valid for category axes)
-          .growth    - True if axis can grow
-          .circular  - True if axis wraps around
-        """
-        return self._ax.options
-
-    def size(self):
-        """
-        Return number of bins excluding under- and overflow.
-        """
-        return self._ax.size
-
-    def extent(self):
-        """
-        Return number of bins including under- and overflow.
-        """
-        return self._ax.extent
-
-    def edges(self):
-        return self._ax.edges
-
-    def centers(self):
-        """
-        An array of bin centers.
-        """
-        return self._ax.centers
-
-    def widths(self):
-        """
-        An array of bin widths.
-        """
-        return self._ax.widths
-
-
 # Contains all common methods and properties for Regular axes
 @register(
     {
@@ -263,7 +215,9 @@ class CppAxisMixin(object):
         ca.regular_circular,
     }
 )
-class BaseRegular(Axis):
+@set_module("boost_histogram.axis")
+@set_family(MAIN_FAMILY)
+class Regular(Axis):
     __slots__ = ()
 
     @inject_signature(
@@ -339,12 +293,6 @@ class BaseRegular(Axis):
         else:
             raise KeyError("Unsupported collection of options")
 
-
-@set_module("boost_histogram.axis")
-@set_family(MAIN_FAMILY)
-class Regular(BaseRegular, MainAxisMixin):
-    __slots__ = ()
-
     def _repr_args(self):
         "Return inner part of signature for use in repr"
 
@@ -367,17 +315,6 @@ class Regular(BaseRegular, MainAxisMixin):
         return None
 
 
-@set_module("boost_histogram.cpp.axis")
-@set_family(CPP_FAMILY)
-class regular(BaseRegular, CppAxisMixin):
-    __slots__ = ()
-
-    def transform(self):
-        if hasattr(self._ax, "transform"):
-            return cast(self, self._ax.transform, AxisTransform)
-        return None
-
-
 @register(
     {
         ca.variable_none,
@@ -388,7 +325,9 @@ class regular(BaseRegular, CppAxisMixin):
         ca.variable_circular,
     }
 )
-class BaseVariable(Axis):
+@set_family(MAIN_FAMILY)
+@set_module("boost_histogram.axis")
+class Variable(Axis):
     __slots__ = ()
 
     @inject_signature(
@@ -443,12 +382,6 @@ class BaseVariable(Axis):
         else:
             raise KeyError("Unsupported collection of options")
 
-
-@set_family(MAIN_FAMILY)
-@set_module("boost_histogram.axis")
-class Variable(BaseVariable, MainAxisMixin):
-    __slots__ = ()
-
     def _repr_args(self):
         "Return inner part of signature for use in repr"
 
@@ -458,12 +391,6 @@ class Variable(BaseVariable, MainAxisMixin):
             return "[{}]".format(", ".join(format(v, "g") for v in self.edges))
 
 
-@set_family(CPP_FAMILY)
-@set_module("boost_histogram.cpp.axis")
-class variable(BaseVariable, CppAxisMixin):
-    __slots__ = ()
-
-
 @register(
     {
         ca.integer_none,
@@ -474,7 +401,9 @@ class variable(BaseVariable, CppAxisMixin):
         ca.integer_circular,
     }
 )
-class BaseInteger(Axis):
+@set_family(MAIN_FAMILY)
+@set_module("boost_histogram.axis")
+class Integer(Axis):
     __slots__ = ()
 
     @inject_signature(
@@ -529,26 +458,41 @@ class BaseInteger(Axis):
         else:
             raise KeyError("Unsupported collection of options")
 
-
-@set_family(MAIN_FAMILY)
-@set_module("boost_histogram.axis")
-class Integer(BaseInteger, MainAxisMixin):
-    __slots__ = ()
-
     def _repr_args(self):
         "Return inner part of signature for use in repr"
 
         return "{start:g}, {stop:g}".format(start=self.edges[0], stop=self.edges[-1])
 
 
-@set_family(CPP_FAMILY)
-@set_module("boost_histogram.cpp.axis")
-class integer(BaseInteger, CppAxisMixin):
+class BaseCategory(Axis):
     __slots__ = ()
 
+    def _repr_kwargs(self):
+        """
+        Return options for use in repr. Metadata is last,
+        just in case it spans multiple lines.
 
+
+        This is specialized for Category axes to avoid repeating
+        the flow arguments unnecessarily.
+        """
+
+        ret = ""
+        if self.options.growth:
+            ret += ", growth=True"
+        elif self.options.circular:
+            ret += ", circular=True"
+
+        if self.metadata is not None:
+            ret += ", metadata={0!r}".format(self.metadata)
+
+        return ret
+
+
+@set_family(MAIN_FAMILY)
+@set_module("boost_histogram.axis")
 @register({ca.category_str_growth, ca.category_str})
-class BaseStrCategory(Axis):
+class StrCategory(BaseCategory):
     __slots__ = ()
 
     @inject_signature("self, categories, *, metadata=None, growth=False")
@@ -595,9 +539,16 @@ class BaseStrCategory(Axis):
                 "index(value) must be a string or iterable of strings for a StrCategory axis"
             )
 
+    def _repr_args(self):
+        "Return inner part of signature for use in repr"
 
+        return "[{0}]".format(", ".join(repr(c) for c in self))
+
+
+@set_family(MAIN_FAMILY)
+@set_module("boost_histogram.axis")
 @register({ca.category_int, ca.category_int_growth})
-class BaseIntCategory(Axis):
+class IntCategory(BaseCategory):
     __slots__ = ()
 
     @inject_signature("self, categories, *, metadata=None, growth=False")
@@ -629,69 +580,17 @@ class BaseIntCategory(Axis):
         else:
             raise KeyError("Unsupported collection of options")
 
-
-class CategoryMixin(object):
-    __slots__ = ()
-
-    def _repr_kwargs(self):
-        """
-        Return options for use in repr. Metadata is last,
-        just in case it spans multiple lines.
-
-
-        This is specialized for Category axes to avoid repeating
-        the flow arguments unnecessarily.
-        """
-
-        ret = ""
-        if self.options.growth:
-            ret += ", growth=True"
-        elif self.options.circular:
-            ret += ", circular=True"
-
-        if self.metadata is not None:
-            ret += ", metadata={0!r}".format(self.metadata)
-
-        return ret
-
-
-@set_family(MAIN_FAMILY)
-@set_module("boost_histogram.axis")
-class StrCategory(BaseStrCategory, CategoryMixin, MainAxisMixin):
-    __slots__ = ()
-
-    def _repr_args(self):
-        "Return inner part of signature for use in repr"
-
-        return "[{0}]".format(", ".join(repr(c) for c in self))
-
-
-@set_family(MAIN_FAMILY)
-@set_module("boost_histogram.axis")
-class IntCategory(BaseIntCategory, CategoryMixin, MainAxisMixin):
-    __slots__ = ()
-
     def _repr_args(self):
         "Return inner part of signature for use in repr"
 
         return "[{0}]".format(", ".join(format(c, "g") for c in self))
 
 
-@set_family(CPP_FAMILY)
-@set_module("boost_histogram.cpp.axis")
-class int_category(BaseIntCategory, CppAxisMixin):
-    __slots__ = ()
-
-
-@set_family(CPP_FAMILY)
-@set_module("boost_histogram.cpp.axis")
-class str_category(BaseStrCategory, CppAxisMixin):
-    __slots__ = ()
-
-
 # Contains all common methods and properties for the boolean axis
 @register({ca.boolean})
-class BaseBoolean(Axis):
+@set_family(MAIN_FAMILY)
+@set_module("boost_histogram.axis")
+class Boolean(Axis):
     __slots__ = ()
 
     @inject_signature("self, *, metadata=None")
@@ -709,12 +608,6 @@ class BaseBoolean(Axis):
 
         self._ax = ca.boolean(metadata)
 
-
-@set_family(MAIN_FAMILY)
-@set_module("boost_histogram.axis")
-class Boolean(BaseBoolean, MainAxisMixin):
-    __slots__ = ()
-
     def _repr_args(self):
         "Return inner part of signature for use in repr"
         return ""
